==> scrolling_calendar-0.0.1.tar.gz: lib/calendar_day.dart <==
import 'package:flutter/material.dart';
import 'package:meta/meta.dart';
import 'package:platform_aware/platform_aware_tappable.dart';

class CalendarDay extends StatelessWidget {
  final bool selected;
  final DateTime date;
  final VoidCallback onTap;
  final Iterable<Color> colorMarkers;

  CalendarDay(
      {@required this.selected, @required this.date, @required this.onTap, @required this.colorMarkers});

  @override
  Widget build(BuildContext context) => Expanded(
      child: PlatformAwareTappable(
          onTap: this.onTap,
          child: Column(children: <Widget>[
            Container(
                decoration: selected
                    ? BoxDecoration(
                        color: Theme.of(context).accentColor,
                        shape: BoxShape.circle,
                      )
                    : null,
                width: 30.0,
                height: 30.0,
                margin: EdgeInsets.only(bottom: 4.0, top: 8.0),
                child: Column(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: <Widget>[
                      Text(
                        date.day.toString(),
                        textAlign: TextAlign.center,
                        style: selected
                            ? Theme.of(context).accentTextTheme.body2
                            : Theme.of(context).textTheme.body2,
                      )
                    ])),
            Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: colorMarkers
                      .map((color) => Container(
                          decoration: BoxDecoration(
                            color: color,
                            shape: BoxShape.circle,
                          ),
                          padding: EdgeInsets.all(3.0)))
                      .toList()),

          ])));
}

==> scrolling_calendar-0.0.2.tar.gz: lib/calendar_day.dart <==
import 'package:flutter/material.dart';
import 'package:meta/meta.dart';
import 'package:platform_aware/platform_aware_tappable.dart';

class CalendarDay extends StatelessWidget {
  final bool selected;
  final DateTime date;
  final VoidCallback onTap;
  final Iterable<Color> colorMarkers;

  CalendarDay(
      {@required this.selected,
      @required this.date,
      @required this.onTap,
      @required this.colorMarkers});

  @override
  Widget build(BuildContext context) => Expanded(
      child: PlatformAwareTappable(
          onTap: this.onTap,
          child: Column(children: <Widget>[
            Container(
                decoration: selected
                    ? BoxDecoration(
                        color: Theme.of(context).accentColor,
                        shape: BoxShape.circle,
                      )
                    : null,
                width: 30.0,
                height: 30.0,
                margin: EdgeInsets.only(bottom: 4.0, top: 8.0),
                child: Column(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: <Widget>[
                      Text(
                        date.day.toString(),
                        textAlign: TextAlign.center,
                        style: selected
                            ? Theme.of(context).accentTextTheme.body2
                            : Theme.of(context).textTheme.body2,
                      )
                    ])),
            Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: colorMarkers
                    .map((color) => Container(
                        decoration: BoxDecoration(
                          color: color,
                          shape: BoxShape.circle,
                        ),
                        padding: EdgeInsets.all(3.0)))
                    .toList()),
          ])));
}
